@@ -5,7 +5,7 @@ QCoro::Task<QByteArray> listDir(const QString &dirPath) {
     auto process = qCoro(basicProcess);
     qDebug() << "Starting ls...";
     co_await process.start(QStringLiteral("/bin/ls"), {dirPath});
-    qDebug() << "Ls started, reading directory...";
+    qDebug() << "ls started, reading directory...";
 
     co_await process.waitForFinished();
     qDebug() << "Done";
